@@ -18,7 +18,9 @@ if __name__ == '__main__':
     print(rsp.json())
     rsp = requests.post(url + '/scan/start',
                         json={'positions': [(1.0, 1.0), (3.0, 3.0)]})
-    rsp.raise_for_status()
+    if not rsp.status_code == 200:
+        print(rsp.json())
+        rsp.raise_for_status()
     rsp = requests.get(url + '/info')
 
     rsp.raise_for_status()
